@@ -51,12 +51,10 @@ package com.openexchange.mobile.configuration.json.osgi;
 
 import static com.openexchange.mobile.configuration.json.osgi.MobilityProvisioningServiceRegistry.getInstance;
 import javax.servlet.ServletException;
-import org.apache.commons.logging.Log;
 import org.osgi.service.http.HttpService;
 import org.osgi.service.http.NamespaceException;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
-import com.openexchange.log.LogFactory;
 import com.openexchange.mobile.configuration.json.action.ActionService;
 import com.openexchange.mobile.configuration.json.servlet.MobilityProvisioningServlet;
 import com.openexchange.osgi.HousekeepingActivator;
@@ -68,7 +66,7 @@ import com.openexchange.osgi.HousekeepingActivator;
  */
 public class MobilityProvisioningActivator extends HousekeepingActivator {
 
-    private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MobilityProvisioningActivator.class));
+    private static transient final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MobilityProvisioningActivator.class);
     private final static String SERVLET_PATH_APPENDIX = "mobilityprovisioning";
 
 	public MobilityProvisioningActivator() {
@@ -82,9 +80,7 @@ public class MobilityProvisioningActivator extends HousekeepingActivator {
 
 	@Override
 	protected void handleAvailability(final Class<?> clazz) {
-		if (LOG.isWarnEnabled()) {
-			LOG.warn("Absent service: " + clazz.getName());
-		}
+		LOG.warn("Absent service: {}", clazz.getName());
 		final Object service = getService(clazz);
 		if (service instanceof HttpService) {
 		    final DispatcherPrefixService dispatcherPrefixService = getService(DispatcherPrefixService.class);
@@ -93,11 +89,11 @@ public class MobilityProvisioningActivator extends HousekeepingActivator {
                 try {
                     ((HttpService) service).registerServlet(alias, new MobilityProvisioningServlet(), null, null);
                 } catch (final ServletException e) {
-                    LOG.error("Unable to register servlet for " + alias, e);
+                    LOG.error("Unable to register servlet for {}", alias, e);
                 } catch (final NamespaceException e) {
-                    LOG.error("Unable to register servlet for " + alias, e);
+                    LOG.error("Unable to register servlet for {}", alias, e);
                 } catch (final Exception e) {
-                    LOG.error("Unable to register servlet for " + alias, e);
+                    LOG.error("Unable to register servlet for {}", alias, e);
                 }
 		    }
 		}
@@ -106,9 +102,7 @@ public class MobilityProvisioningActivator extends HousekeepingActivator {
 
 	@Override
 	protected void handleUnavailability(final Class<?> clazz) {
-		if (LOG.isInfoEnabled()) {
-			LOG.info("Re-available service: " + clazz.getName());
-		}
+		LOG.info("Re-available service: {}", clazz.getName());
 		if (HttpService.class.equals(clazz)) {
 		    final HttpService service = getService(HttpService.class);
 		    final DispatcherPrefixService dispatcherPrefixService = getService(DispatcherPrefixService.class);
@@ -141,7 +135,7 @@ public class MobilityProvisioningActivator extends HousekeepingActivator {
             track(ActionService.class, new ActionServiceListener(context));
             openTrackers();
 		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
+			LOG.error("", t);
 			throw t instanceof Exception ? (Exception) t : new Exception(t);
 		}
 
@@ -162,7 +156,7 @@ public class MobilityProvisioningActivator extends HousekeepingActivator {
             getInstance().clearRegistry();
             getInstance().clearActionServices();
 		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
+			LOG.error("", t);
 			throw t instanceof Exception ? (Exception) t : new Exception(t);
 		}
 	}
